==> apache-seatunnel-2.3.3-src.tar.gz: apache-seatunnel-2.3.3-src/seatunnel-connectors-v2/connector-clickhouse/src/main/java/org/apache/seatunnel/connectors/seatunnel/clickhouse/config/ClickhouseFileCopyMethod.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.seatunnel.connectors.seatunnel.clickhouse.config;

import org.apache.seatunnel.common.exception.CommonErrorCode;
import org.apache.seatunnel.connectors.seatunnel.clickhouse.exception.ClickhouseConnectorException;

public enum ClickhouseFileCopyMethod {
    SCP("scp"),
    RSYNC("rsync"),
    ;
    private final String name;

    ClickhouseFileCopyMethod(String name) {
        this.name = name;
    }

    public String getName() {
        return name;
    }

    public static ClickhouseFileCopyMethod from(String name) {
        for (ClickhouseFileCopyMethod clickhouseFileCopyMethod :
                ClickhouseFileCopyMethod.values()) {
            if (clickhouseFileCopyMethod.getName().equalsIgnoreCase(name)) {
                return clickhouseFileCopyMethod;
            }
        }
        throw new ClickhouseConnectorException(
                CommonErrorCode.ILLEGAL_ARGUMENT, "Unknown ClickhouseFileCopyMethod: " + name);
    }
}

==> apache-seatunnel-2.3.6-src.tar.gz: apache-seatunnel-2.3.6-src/seatunnel-connectors-v2/connector-clickhouse/src/main/java/org/apache/seatunnel/connectors/seatunnel/clickhouse/config/ClickhouseFileCopyMethod.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.seatunnel.connectors.seatunnel.clickhouse.config;

import org.apache.seatunnel.common.exception.CommonErrorCodeDeprecated;
import org.apache.seatunnel.connectors.seatunnel.clickhouse.exception.ClickhouseConnectorException;

public enum ClickhouseFileCopyMethod {
    SCP("scp"),
    RSYNC("rsync"),
    ;
    private final String name;

    ClickhouseFileCopyMethod(String name) {
        this.name = name;
    }

    public String getName() {
        return name;
    }

    public static ClickhouseFileCopyMethod from(String name) {
        for (ClickhouseFileCopyMethod clickhouseFileCopyMethod :
                ClickhouseFileCopyMethod.values()) {
            if (clickhouseFileCopyMethod.getName().equalsIgnoreCase(name)) {
                return clickhouseFileCopyMethod;
            }
        }
        throw new ClickhouseConnectorException(
                CommonErrorCodeDeprecated.ILLEGAL_ARGUMENT,
                "Unknown ClickhouseFileCopyMethod: " + name);
    }
}
